@@ -209,33 +209,9 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
 
-#-------------------------------------Request to extract metadata for each user-------------------------------#
-
-def body_users(user_list):
-    len_user_list = len(user_list)
-    body_tweets = json.dumps({
-	  "screen_names": user_list,
-	  "item_limit": len_user_list,
-	  "show_params": [
-		"created_at",
-		  "default_profile",
-		  "default_profile_image",
-		  "description",
-		  "favourites_count",
-		  "followees","followers",
-		  "listed_count","screen_name",
-		  "statuses_count",
-		  "verified"],
-	  "filter_options": { }
-	})
-    return body_tweets
-
-
-    
-
 def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, iter_tw, fichero):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
-    profile_iter = 300
+    profile_iter = len(node_list)
     k=0
     auth = tweepy.OAuthHandler(consumerKey[0], consumerSecret[0])
     auth.set_access_token(accessToken[0], accessTokenSecret[0])
@@ -738,9 +714,16 @@ def filter_possible_irregular_profiles(data_join):
 
 	
 def evaluate_NLP_profiles(df):
-	for i in range(len(df)):
-		tweets = df.iloc[i]["text_tweets_days_list"]
+	df_evaluate = df[(df["evaluate_NLP"] !="No") & df["evaluate_NLP"] !="More Data"]
+	node_list_moreData = list(df[df["evaluate_NLP"]=="More Data"])
+	if len(node_list_moreData) >0:
+		df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,5,"fichero_guardar_noData.csv")
+		df_metadata_moreData = select_possible_fakes(df_metadata_moreData)
+		df_metadata_moreData = df_metadata_moreData[(df_metadata_moreData["evaluate_NLP"] !="No") & df_metadata_moreData["evaluate_NLP"] !="More Data"]
+		df_evaluate = df_evaluate.append(df_metadata_moreData, ignore_index=True)
+	for i in range(len(df_evaluate)):
+		tweets = df_evaluate.iloc[i]["text_tweets_days_list"]
 		tweets_join = [j for i in tweets for j in i]
 		tweets_df = pd.DataFrame(tweets_join)
 		tweets_df.to_csv("tweets_profile_example.csv",index=False)
-	return tweets_df
\ No newline at end of file
+	return df_evaluate
\ No newline at end of file
